@@ -1,40 +1,101 @@
-import datetime
+import datetime as dt
 import locale
 import platform
-
 import unicodedata
+
 import pytest
+from khal.calendar_display import (getweeknumber, str_week, vertical_month,
+                                   get_calendar_color, get_color_list)
 
-from khal.calendar_display import vertical_month, getweeknumber, str_week
-
-
-today = datetime.date.today()
-yesterday = today - datetime.timedelta(days=1)
-tomorrow = today + datetime.timedelta(days=1)
+today = dt.date.today()
+yesterday = today - dt.timedelta(days=1)
+tomorrow = today + dt.timedelta(days=1)
 
 
 def test_getweeknumber():
-    assert getweeknumber(datetime.date(2011, 12, 12)) == 50
-    assert getweeknumber(datetime.date(2011, 12, 31)) == 52
-    assert getweeknumber(datetime.date(2012, 1, 1)) == 52
-    assert getweeknumber(datetime.date(2012, 1, 2)) == 1
+    assert getweeknumber(dt.date(2011, 12, 12)) == 50
+    assert getweeknumber(dt.date(2011, 12, 31)) == 52
+    assert getweeknumber(dt.date(2012, 1, 1)) == 52
+    assert getweeknumber(dt.date(2012, 1, 2)) == 1
 
 
 def test_str_week():
-    aday = datetime.date(2012, 6, 1)
-    bday = datetime.date(2012, 6, 8)
-    week = [datetime.date(2012, 6, 6),
-            datetime.date(2012, 6, 7),
-            datetime.date(2012, 6, 8),
-            datetime.date(2012, 6, 9),
-            datetime.date(2012, 6, 10),
-            datetime.date(2012, 6, 11),
-            datetime.date(2012, 6, 12),
-            datetime.date(2012, 6, 13)]
+    aday = dt.date(2012, 6, 1)
+    bday = dt.date(2012, 6, 8)
+    week = [dt.date(2012, 6, 6),
+            dt.date(2012, 6, 7),
+            dt.date(2012, 6, 8),
+            dt.date(2012, 6, 9),
+            dt.date(2012, 6, 10),
+            dt.date(2012, 6, 11),
+            dt.date(2012, 6, 12),
+            dt.date(2012, 6, 13)]
     assert str_week(week, aday) == ' 6  7  8  9 10 11 12 13 '
     assert str_week(week, bday) == ' 6  7 \x1b[7m 8\x1b[0m  9 10 11 12 13 '
 
 
+class testCollection():
+    def __init__(self):
+        self._calendars = {}
+
+    def addCalendar(self, name, color, priority):
+        self._calendars[name] = {'color': color, 'priority': priority}
+
+
+def test_get_calendar_color():
+
+    exampleCollection = testCollection()
+    exampleCollection.addCalendar('testCalendar1', 'dark red', 20)
+    exampleCollection.addCalendar('testCalendar2', 'light green', 10)
+    exampleCollection.addCalendar('testCalendar3', '', 10)
+
+    assert get_calendar_color('testCalendar1', 'light blue', exampleCollection) == 'dark red'
+    assert get_calendar_color('testCalendar2', 'light blue', exampleCollection) == 'light green'
+
+    # test default color
+    assert get_calendar_color('testCalendar3', 'light blue', exampleCollection) == 'light blue'
+
+
+def test_get_color_list():
+
+    exampleCalendarList = ['testCalendar1', 'testCalendar2']
+
+    # test different priorities
+    exampleCollection1 = testCollection()
+    exampleCollection1.addCalendar('testCalendar1', 'dark red', 20)
+    exampleCollection1.addCalendar('testCalendar2', 'light green', 10)
+
+    testList1 = get_color_list(exampleCalendarList, 'light_blue', exampleCollection1)
+    assert 'dark red' in testList1
+    assert len(testList1) == 1
+
+    # test same priorities
+    exampleCollection2 = testCollection()
+    exampleCollection2.addCalendar('testCalendar1', 'dark red', 20)
+    exampleCollection2.addCalendar('testCalendar2', 'light green', 20)
+
+    testList2 = get_color_list(exampleCalendarList, 'light_blue', exampleCollection2)
+    assert 'dark red' in testList2
+    assert 'light green' in testList2
+    assert len(testList2) == 2
+
+    # test duplicated colors
+    exampleCollection3 = testCollection()
+    exampleCollection3.addCalendar('testCalendar1', 'dark red', 20)
+    exampleCollection3.addCalendar('testCalendar2', 'dark red', 20)
+
+    testList3 = get_color_list(exampleCalendarList, 'light_blue', exampleCollection3)
+    assert len(testList3) == 1
+
+    # test indexing operator (required by str_highlight_day())
+    exampleCollection4 = testCollection()
+    exampleCollection4.addCalendar('testCalendar1', 'dark red', 20)
+    exampleCollection4.addCalendar('testCalendar2', 'dark red', 20)
+
+    testList3 = get_color_list(exampleCalendarList, 'light_blue', exampleCollection4)
+    assert testList3[0] == 'dark red'
+
+
 example1 = [
     '\x1b[1m    Mo Tu We Th Fr Sa Su \x1b[0m',
     '\x1b[1mDec \x1b[0m28 29 30  1  2  3  4 ',
@@ -52,6 +113,23 @@ example1 = [
     '    20 21 22 23 24 25 26 ',
     '\x1b[1mMar \x1b[0m27 28 29  1  2  3  4 ']
 
+example2 = [
+    '\x1b[1m    Mo Tu We Th Fr Sa Su \x1b[0m',
+    '    28 29 30  1  2  3  4 ',
+    '\x1b[1mDec \x1b[0m 5  6  7  8  9 10 11 ',
+    '    \x1b[7m12\x1b[0m 13 14 15 16 17 18 ',
+    '    19 20 21 22 23 24 25 ',
+    '    26 27 28 29 30 31  1 ',
+    '\x1b[1mJan \x1b[0m 2  3  4  5  6  7  8 ',
+    '     9 10 11 12 13 14 15 ',
+    '    16 17 18 19 20 21 22 ',
+    '    23 24 25 26 27 28 29 ',
+    '    30 31  1  2  3  4  5 ',
+    '\x1b[1mFeb \x1b[0m 6  7  8  9 10 11 12 ',
+    '    13 14 15 16 17 18 19 ',
+    '    20 21 22 23 24 25 26 ',
+    '    27 28 29  1  2  3  4 ']
+
 
 example_weno = [
     '\x1b[1m    Mo Tu We Th Fr Sa Su   \x1b[0m',
@@ -194,17 +272,22 @@ def test_vertical_month():
     try:
         locale.setlocale(locale.LC_ALL, 'en_US.UTF-8')
         vert_str = vertical_month(month=12, year=2011,
-                                  today=datetime.date(2011, 12, 12))
+                                  today=dt.date(2011, 12, 12))
         assert vert_str == example1
 
+        vert_str = vertical_month(month=12, year=2011,
+                                  today=dt.date(2011, 12, 12),
+                                  monthdisplay='firstfullweek')
+        assert vert_str == example2
+
         weno_str = vertical_month(month=12, year=2011,
-                                  today=datetime.date(2011, 12, 12),
+                                  today=dt.date(2011, 12, 12),
                                   weeknumber='right')
         assert weno_str == example_weno
 
         we_start_su_str = vertical_month(
             month=12, year=2011,
-            today=datetime.date(2011, 12, 12),
+            today=dt.date(2011, 12, 12),
             firstweekday=6)
         assert we_start_su_str == example_we_start_su
     except locale.Error as error:
@@ -223,7 +306,7 @@ def test_vertical_month_unicode():
     try:
         locale.setlocale(locale.LC_ALL, 'de_DE.UTF-8')
         vert_str = vertical_month(month=12, year=2011,
-                                  today=datetime.date(2011, 12, 12))
+                                  today=dt.date(2011, 12, 12))
         # de_DE locale on at least Net and FreeBSD is different from the one
         # commonly used on linux systems
         if platform.system() == 'FreeBSD':
@@ -252,7 +335,7 @@ def test_vertical_month_unicode_weekdeays():
     try:
         locale.setlocale(locale.LC_ALL, 'cs_CZ.UTF-8')
         vert_str = vertical_month(month=12, year=2011,
-                                  today=datetime.date(2011, 12, 12))
+                                  today=dt.date(2011, 12, 12))
         assert [line.lower() for line in vert_str] == [line.lower() for line in example_cz]
         '\n'.join(vert_str)  # issue 142/293
     except locale.Error as error:
@@ -279,7 +362,7 @@ def test_vertical_month_unicode_weekdeays_gr():
     try:
         locale.setlocale(locale.LC_ALL, 'el_GR.UTF-8')
         vert_str = vertical_month(month=12, year=2011,
-                                  today=datetime.date(2011, 12, 12))
+                                  today=dt.date(2011, 12, 12))
         # on some OSes, Greek locale's abbreviated day of the week and
         # month names have accents, on some they haven't
         assert strip_accents('\n'.join([line.lower() for line in vert_str])) == \
@@ -304,7 +387,7 @@ def test_vertical_month_abbr_fr():
     try:
         locale.setlocale(locale.LC_ALL, 'fr_FR.UTF-8')
         vert_str = vertical_month(month=12, year=2011,
-                                  today=datetime.date(2011, 12, 12))
+                                  today=dt.date(2011, 12, 12))
         assert '\n'.join(vert_str) == '\n'.join(example_fr)
     except locale.Error as error:
         if str(error) == 'unsupported locale setting':
