@@ -1,16 +1,13 @@
-import datetime
+import datetime as dt
 import os
 import sys
-from unittest import mock
-from datetime import timedelta
 
 import pytest
-from freezegun import freeze_time
 from click.testing import CliRunner
+from freezegun import freeze_time
+from khal.cli import main_ikhal, main_khal
 
-from khal.cli import main_khal, main_ikhal
-
-from .utils import _get_text, _get_ics_filepath
+from .utils import _get_ics_filepath, _get_text
 
 
 class CustomCliRunner(CliRunner):
@@ -47,8 +44,7 @@ def runner(tmpdir, monkeypatch):
     monkeypatch.setattr('xdg.BaseDirectory.xdg_config_home', str(xdg_config_home))
     monkeypatch.setattr('xdg.BaseDirectory.xdg_config_dirs', [str(xdg_config_home)])
 
-    def inner(default_command='list', print_new=False, default_calendar=True, days=2,
-              **kwargs):
+    def inner(print_new=False, default_calendar=True, days=2, **kwargs):
         if default_calendar:
             default_calendar = 'default_calendar = one'
         else:
@@ -56,7 +52,6 @@ def runner(tmpdir, monkeypatch):
         if not os.path.exists(str(xdg_config_home.join('khal'))):
             os.makedirs(str(xdg_config_home.join('khal')))
         config_file.write(config_template.format(
-            default_command=default_command,
             delta=str(days) + 'd',
             calpath=str(calendar), calpath2=str(calendar2), calpath3=str(calendar3),
             default_calendar=default_calendar,
@@ -96,7 +91,6 @@ longdatetimeformat = %d.%m.%Y %H:%M
 firstweekday = 0
 
 [default]
-default_command = {default_command}
 {default_calendar}
 timedelta = {delta}
 print_new = {print_new}
@@ -107,11 +101,11 @@ path = {dbpath}
 
 
 def test_direct_modification(runner):
-    runner = runner(default_command='list')
+    runner = runner()
 
     result = runner.invoke(main_khal, ['list'])
-    assert not result.exception
     assert result.output == 'No events\n'
+    assert not result.exception
 
     cal_dt = _get_text('event_dt_simple')
     event = runner.calendars['one'].join('test.ics')
@@ -129,19 +123,18 @@ def test_direct_modification(runner):
 
 
 def test_simple(runner):
-    runner = runner(default_command='list', days=2)
-
-    result = runner.invoke(main_khal)
+    runner = runner(days=2)
+    result = runner.invoke(main_khal, ['list'])
     assert not result.exception
     assert result.output == 'No events\n'
 
-    now = datetime.datetime.now().strftime('%d.%m.%Y')
+    now = dt.datetime.now().strftime('%d.%m.%Y')
     result = runner.invoke(
         main_khal, 'new {} 18:00 myevent'.format(now).split())
     assert result.output == ''
     assert not result.exception
 
-    result = runner.invoke(main_khal)
+    result = runner.invoke(main_khal, ['list'])
     print(result.output)
     assert 'myevent' in result.output
     assert '18:00' in result.output
@@ -151,32 +144,31 @@ def test_simple(runner):
 
 
 def test_simple_color(runner):
-    runner = runner(default_command='list', days=2)
-
-    now = datetime.datetime.now().strftime('%d.%m.%Y')
+    runner = runner(days=2)
+    now = dt.datetime.now().strftime('%d.%m.%Y')
     result = runner.invoke(main_khal, 'new {} 18:00 myevent'.format(now).split())
     assert result.output == ''
     assert not result.exception
 
-    result = runner.invoke(main_khal, color=True)
+    result = runner.invoke(main_khal, ['list'], color=True)
     assert not result.exception
     assert '\x1b[34m' in result.output
 
 
 def test_days(runner):
-    runner = runner(default_command='list', days=9)
+    runner = runner(days=9)
 
-    when = (datetime.datetime.now() + timedelta(days=7)).strftime('%d.%m.%Y')
+    when = (dt.datetime.now() + dt.timedelta(days=7)).strftime('%d.%m.%Y')
     result = runner.invoke(main_khal, 'new {} 18:00 nextweek'.format(when).split())
     assert result.output == ''
     assert not result.exception
 
-    when = (datetime.datetime.now() + timedelta(days=30)).strftime('%d.%m.%Y')
+    when = (dt.datetime.now() + dt.timedelta(days=30)).strftime('%d.%m.%Y')
     result = runner.invoke(main_khal, 'new {} 18:00 nextmonth'.format(when).split())
     assert result.output == ''
     assert not result.exception
 
-    result = runner.invoke(main_khal)
+    result = runner.invoke(main_khal, ['list'])
     assert 'nextweek' in result.output
     assert 'nextmonth' not in result.output
     assert '18:00' in result.output
@@ -185,7 +177,7 @@ def test_days(runner):
 
 def test_notstarted(runner):
     with freeze_time('2015-6-1 15:00'):
-        runner = runner(default_command='calendar', days=2)
+        runner = runner(days=2)
         for command in [
                 'new 30.5.2015 5.6.2015 long event',
                 'new 2.6.2015 4.6.2015 two day event',
@@ -248,8 +240,8 @@ Tomorrow, 02.06.2015
 
 def test_calendar(runner):
     with freeze_time('2015-6-1'):
-        runner = runner(default_command='calendar', days=0)
-        result = runner.invoke(main_khal)
+        runner = runner(days=0)
+        result = runner.invoke(main_khal, ['calendar'])
         assert not result.exception
         assert result.exit_code == 0
         output = '\n'.join([
@@ -275,8 +267,8 @@ def test_calendar(runner):
 
 def test_long_calendar(runner):
     with freeze_time('2015-6-1'):
-        runner = runner(default_command='calendar', days=100)
-        result = runner.invoke(main_khal)
+        runner = runner(days=100)
+        result = runner.invoke(main_khal, ['calendar'])
         assert not result.exception
         assert result.exit_code == 0
         output = '\n'.join([
@@ -305,24 +297,16 @@ def test_long_calendar(runner):
 
 
 def test_default_command_empty(runner):
-    runner = runner(default_command='', days=2)
+    runner = runner(days=2)
 
     result = runner.invoke(main_khal)
     assert result.exception
-    assert result.exit_code == 1
+    assert result.exit_code == 2
     assert result.output.startswith('Usage: ')
 
 
-def test_default_command_nonempty(runner):
-    runner = runner(default_command='list', days=2)
-
-    result = runner.invoke(main_khal)
-    assert not result.exception
-    assert result.output == 'No events\n'
-
-
 def test_invalid_calendar(runner):
-    runner = runner(default_command='', days=2)
+    runner = runner(days=2)
     result = runner.invoke(
         main_khal, ['new'] + '-a one 18:00 myevent'.split())
     assert not result.exception
@@ -334,7 +318,7 @@ def test_invalid_calendar(runner):
 
 
 def test_attach_calendar(runner):
-    runner = runner(default_command='calendar', days=2)
+    runner = runner(days=2)
     result = runner.invoke(main_khal, ['printcalendars'])
     assert set(result.output.split('\n')[:3]) == set(['one', 'two', 'three'])
     assert not result.exception
@@ -351,24 +335,24 @@ def test_attach_calendar(runner):
     'BEGIN:VCALENDAR\nBEGIN:VTODO\nEND:VTODO\nEND:VCALENDAR\n'
 ])
 def test_no_vevent(runner, tmpdir, contents):
-    runner = runner(default_command='list', days=2)
+    runner = runner(days=2)
     broken_item = runner.calendars['one'].join('broken_item.ics')
     broken_item.write(contents.encode('utf-8'), mode='wb')
 
-    result = runner.invoke(main_khal)
+    result = runner.invoke(main_khal, ['list'])
     assert not result.exception
     assert 'No events' in result.output
 
 
 def test_printformats(runner):
-    runner = runner(default_command='printformats', days=2)
+    runner = runner(days=2)
 
-    result = runner.invoke(main_khal)
-    assert '\n'.join(['longdatetimeformat: 21.12.2013 10:09',
-                      'datetimeformat: 21.12. 10:09',
+    result = runner.invoke(main_khal, ['printformats'])
+    assert '\n'.join(['longdatetimeformat: 21.12.2013 21:45',
+                      'datetimeformat: 21.12. 21:45',
                       'longdateformat: 21.12.2013',
                       'dateformat: 21.12.',
-                      'timeformat: 10:09',
+                      'timeformat: 21:45',
                       '']) == result.output
     assert not result.exception
 
@@ -376,9 +360,9 @@ def test_printformats(runner):
 # "see #810"
 @pytest.mark.xfail
 def test_repeating(runner):
-    runner = runner(default_command='list', days=2)
-    now = datetime.datetime.now().strftime('%d.%m.%Y')
-    end_date = datetime.datetime.now() + datetime.timedelta(days=10)
+    runner = runner(days=2)
+    now = dt.datetime.now().strftime('%d.%m.%Y')
+    end_date = dt.datetime.now() + dt.timedelta(days=10)
     result = runner.invoke(
         main_khal, 'new {} 18:00 myevent -r weekly -u {}'.format(
             now, end_date.strftime('%d.%m.%Y')).split())
@@ -387,9 +371,9 @@ def test_repeating(runner):
 
 
 def test_at(runner):
-    runner = runner(default_command='calendar', days=2)
-    now = datetime.datetime.now().strftime('%d.%m.%Y')
-    end_date = datetime.datetime.now() + datetime.timedelta(days=10)
+    runner = runner(days=2)
+    now = dt.datetime.now().strftime('%d.%m.%Y')
+    end_date = dt.datetime.now() + dt.timedelta(days=10)
     result = runner.invoke(
         main_khal,
         'new {} {} 18:00 myevent'.format(now, end_date.strftime('%d.%m.%Y')).split())
@@ -400,9 +384,9 @@ def test_at(runner):
 
 
 def test_at_day_format(runner):
-    runner = runner(default_command='calendar', days=2)
-    now = datetime.datetime.now().strftime('%d.%m.%Y')
-    end_date = datetime.datetime.now() + datetime.timedelta(days=10)
+    runner = runner(days=2)
+    now = dt.datetime.now().strftime('%d.%m.%Y')
+    end_date = dt.datetime.now() + dt.timedelta(days=10)
     result = runner.invoke(
         main_khal,
         'new {} {} 18:00 myevent'.format(now, end_date.strftime('%d.%m.%Y')).split())
@@ -413,12 +397,11 @@ def test_at_day_format(runner):
 
 
 def test_list(runner):
-    runner = runner(default_command='calendar', days=2)
-    now = datetime.datetime.now().strftime('%d.%m.%Y')
-    end_date = datetime.datetime.now() + datetime.timedelta(days=10)
+    runner = runner(days=2)
+    now = dt.datetime.now().strftime('%d.%m.%Y')
     result = runner.invoke(
         main_khal,
-        'new {} 18:00 myevent'.format(now, end_date.strftime('%d.%m.%Y')).split())
+        'new {} 18:00 myevent'.format(now).split())
     format = '{red}{start-end-time-style}{reset} {title} :: {description}'
     args = ['--color', 'list', '--format', format, '--day-format', 'header', '18:30']
     result = runner.invoke(main_khal, args)
@@ -428,8 +411,8 @@ def test_list(runner):
 
 
 def test_search(runner):
-    runner = runner(default_command='calendar', days=2)
-    now = datetime.datetime.now().strftime('%d.%m.%Y')
+    runner = runner(days=2)
+    now = dt.datetime.now().strftime('%d.%m.%Y')
     result = runner.invoke(main_khal, 'new {} 18:00 myevent'.format(now).split())
     format = '{red}{start-end-time-style}{reset} {title} :: {description}'
     result = runner.invoke(main_khal, ['--color', 'search', '--format', format, 'myevent'])
@@ -487,6 +470,19 @@ def test_import_proper(runner):
     assert result.output == '09.04.-09.04. An Event\n'
 
 
+def test_import_proper_invalid_timezone(runner):
+    runner = runner()
+    result = runner.invoke(
+        main_khal, ['import', _get_ics_filepath('invalid_tzoffset')], input='0\ny\n')
+    assert result.output.startswith(
+        'warning: Invalid timezone offset encountered, timezone information may be wrong')
+    assert not result.exception
+    result = runner.invoke(main_khal, ['search', 'Event'])
+    assert result.output.startswith(
+        'warning: Invalid timezone offset encountered, timezone information may be wrong')
+    assert '02.12. 08:00-02.12. 09:30 Some event' in result.output
+
+
 def test_import_invalid_choice_and_prefix(runner):
     runner = runner()
     result = runner.invoke(main_khal, ['import', _get_ics_filepath('cal_d')], input='9\nth\ny\n')
@@ -497,20 +493,35 @@ def test_import_invalid_choice_and_prefix(runner):
     assert result.output == '09.04.-09.04. An Event\n'
 
 
-def test_import_from_stdin(runner):
+def test_import_from_stdin(runner, monkeypatch):
     ics_data = 'This is some really fake icalendar data'
 
-    with mock.patch('khal.controllers.import_ics') as mocked_import:
-        runner = runner()
-        result = runner.invoke(main_khal, ['import'], input=ics_data)
+    class FakeImport():
+        args, kwargs = None, None
+        call_count = 0
+
+        def clean(self):
+            self.args, self.kwargs = None, None
+
+        def import_ics(self, *args, **kwargs):
+            print('saving args')
+            print(args)
+            self.call_count += 1
+            self.args = args
+            self.kwargs = kwargs
+
+    importer = FakeImport()
+    monkeypatch.setattr('khal.controllers.import_ics', importer.import_ics)
+    runner = runner()
+    result = runner.invoke(main_khal, ['import'], input=ics_data)
 
     assert not result.exception
-    assert mocked_import.call_count == 1
-    assert mocked_import.call_args[1]['ics'] == ics_data
+    assert importer.call_count == 1
+    assert importer.kwargs['ics'] == ics_data
 
 
 def test_interactive_command(runner, monkeypatch):
-    runner = runner(default_command='list', days=2)
+    runner = runner(days=2)
     token = "hooray"
 
     def fake_ui(*a, **kw):
@@ -529,12 +540,12 @@ def test_interactive_command(runner, monkeypatch):
 
 
 def test_color_option(runner):
-    runner = runner(default_command='list', days=2)
+    runner = runner(days=2)
 
-    result = runner.invoke(main_khal, ['--no-color'])
+    result = runner.invoke(main_khal, ['--no-color', 'list'])
     assert result.output == 'No events\n'
 
-    result = runner.invoke(main_khal, ['--color'])
+    result = runner.invoke(main_khal, ['--color', 'list'])
     assert 'No events' in result.output
     assert result.output != 'No events\n'
 
@@ -645,18 +656,21 @@ longdatetimeformat = %Y-%m-%d %H:%M
 
 
 def test_print_ics_command(runner):
-    runner = runner(command='printics', days=2)
+    runner = runner()
     # Input is empty and loading from stdin
-    result = runner.invoke(main_khal, ['-'])
+    result = runner.invoke(main_khal, ['printics', '-'])
     assert result.exception
 
     # Non existing file
     result = runner.invoke(main_khal, ['printics', 'nonexisting_file'])
     assert result.exception
-    assert ('Error: Invalid value for "ics": Could not open file: ' \
-        in result.output or \
-            'Error: Invalid value for "[ICS]": Could not open file:' \
-            in result.output)
+    assert (
+        'Error: Invalid value for "ics": Could not open file: ' in result.output or
+        'Error: Invalid value for "[ICS]": Could not open file:'
+        in result.output or
+        'Error: Invalid value for \'ics\': Could not open file: ' in result.output or
+        'Error: Invalid value for \'[ICS]\': Could not open file:'
+        in result.output)
 
     # Run on test files
     result = runner.invoke(main_khal, ['printics', _get_ics_filepath('cal_d')])
@@ -665,7 +679,7 @@ def test_print_ics_command(runner):
     assert not result.exception
 
     # Test with some nice format strings
-    form = '{title}\t{description}\t{start}\t{start-long}\t{start-date}' \
+    form = '{uid}\t{title}\t{description}\t{start}\t{start-long}\t{start-date}' \
            '\t{start-date-long}\t{start-time}\t{end}\t{end-long}\t{end-date}' \
            '\t{end-date-long}\t{end-time}\t{repeat-symbol}\t{description}' \
            '\t{description-separator}\t{location}\t{calendar}' \
@@ -674,11 +688,11 @@ def test_print_ics_command(runner):
     result = runner.invoke(main_khal, [
         'printics', '-f', form, _get_ics_filepath('cal_dt_two_tz')])
     assert not result.exception
-    assert 24 == len(result.output.split('\t'))
+    assert 25 == len(result.output.split('\t'))
     result = runner.invoke(main_khal, [
         'printics', '-f', form, _get_ics_filepath('cal_dt_two_tz')])
     assert not result.exception
-    assert 24 == len(result.output.split('\t'))
+    assert 25 == len(result.output.split('\t'))
 
 
 def test_printics_read_from_stdin(runner):
@@ -818,6 +832,15 @@ def test_new_interactive(runner):
     assert result.exit_code == 0
 
 
+def test_debug(runner):
+    runner = runner()
+    result = runner.invoke(main_khal, ['-v', 'debug', 'printformats'])
+    assert result.output.startswith('debug: khal 0.')
+    assert 'using the config file at' in result.output
+    assert 'debug: Using config:\ndebug: [calendars]' in result.output
+    assert not result.exception
+
+
 @freeze_time('2015-6-1 8:00')
 def test_new_interactive_extensive(runner):
     runner = runner(print_new='path', default_calendar=False)
