@@ -1,8 +1,8 @@
-from datetime import date, datetime, timedelta
-import icalendar
-import pytz
+import datetime as dt
 
-from khal.khalendar import utils
+import icalendar
+from khal import icalendar as icalendar_helpers, utils
+import pytz
 
 from .utils import _get_text, _get_vevent_file
 
@@ -232,86 +232,86 @@ def _get_vevent(event):
 
 class TestExpand(object):
     dtstartend_berlin = [
-        (berlin.localize(datetime(2013, 3, 1, 14, 0, )),
-         berlin.localize(datetime(2013, 3, 1, 16, 0, ))),
-        (berlin.localize(datetime(2013, 5, 1, 14, 0, )),
-         berlin.localize(datetime(2013, 5, 1, 16, 0, ))),
-        (berlin.localize(datetime(2013, 7, 1, 14, 0, )),
-         berlin.localize(datetime(2013, 7, 1, 16, 0, ))),
-        (berlin.localize(datetime(2013, 9, 1, 14, 0, )),
-         berlin.localize(datetime(2013, 9, 1, 16, 0, ))),
-        (berlin.localize(datetime(2013, 11, 1, 14, 0,)),
-         berlin.localize(datetime(2013, 11, 1, 16, 0,))),
-        (berlin.localize(datetime(2014, 1, 1, 14, 0, )),
-         berlin.localize(datetime(2014, 1, 1, 16, 0, )))
+        (berlin.localize(dt.datetime(2013, 3, 1, 14, 0, )),
+         berlin.localize(dt.datetime(2013, 3, 1, 16, 0, ))),
+        (berlin.localize(dt.datetime(2013, 5, 1, 14, 0, )),
+         berlin.localize(dt.datetime(2013, 5, 1, 16, 0, ))),
+        (berlin.localize(dt.datetime(2013, 7, 1, 14, 0, )),
+         berlin.localize(dt.datetime(2013, 7, 1, 16, 0, ))),
+        (berlin.localize(dt.datetime(2013, 9, 1, 14, 0, )),
+         berlin.localize(dt.datetime(2013, 9, 1, 16, 0, ))),
+        (berlin.localize(dt.datetime(2013, 11, 1, 14, 0,)),
+         berlin.localize(dt.datetime(2013, 11, 1, 16, 0,))),
+        (berlin.localize(dt.datetime(2014, 1, 1, 14, 0, )),
+         berlin.localize(dt.datetime(2014, 1, 1, 16, 0, )))
     ]
 
     dtstartend_utc = [
-        (datetime(2013, 3, 1, 14, 0, tzinfo=pytz.utc),
-         datetime(2013, 3, 1, 16, 0, tzinfo=pytz.utc)),
-        (datetime(2013, 5, 1, 14, 0, tzinfo=pytz.utc),
-         datetime(2013, 5, 1, 16, 0, tzinfo=pytz.utc)),
-        (datetime(2013, 7, 1, 14, 0, tzinfo=pytz.utc),
-         datetime(2013, 7, 1, 16, 0, tzinfo=pytz.utc)),
-        (datetime(2013, 9, 1, 14, 0, tzinfo=pytz.utc),
-         datetime(2013, 9, 1, 16, 0, tzinfo=pytz.utc)),
-        (datetime(2013, 11, 1, 14, 0, tzinfo=pytz.utc),
-         datetime(2013, 11, 1, 16, 0, tzinfo=pytz.utc)),
-        (datetime(2014, 1, 1, 14, 0, tzinfo=pytz.utc),
-         datetime(2014, 1, 1, 16, 0, tzinfo=pytz.utc))
+        (dt.datetime(2013, 3, 1, 14, 0, tzinfo=pytz.utc),
+         dt.datetime(2013, 3, 1, 16, 0, tzinfo=pytz.utc)),
+        (dt.datetime(2013, 5, 1, 14, 0, tzinfo=pytz.utc),
+         dt.datetime(2013, 5, 1, 16, 0, tzinfo=pytz.utc)),
+        (dt.datetime(2013, 7, 1, 14, 0, tzinfo=pytz.utc),
+         dt.datetime(2013, 7, 1, 16, 0, tzinfo=pytz.utc)),
+        (dt.datetime(2013, 9, 1, 14, 0, tzinfo=pytz.utc),
+         dt.datetime(2013, 9, 1, 16, 0, tzinfo=pytz.utc)),
+        (dt.datetime(2013, 11, 1, 14, 0, tzinfo=pytz.utc),
+         dt.datetime(2013, 11, 1, 16, 0, tzinfo=pytz.utc)),
+        (dt.datetime(2014, 1, 1, 14, 0, tzinfo=pytz.utc),
+         dt.datetime(2014, 1, 1, 16, 0, tzinfo=pytz.utc))
     ]
 
     dtstartend_float = [
-        (datetime(2013, 3, 1, 14, 0),
-         datetime(2013, 3, 1, 16, 0)),
-        (datetime(2013, 5, 1, 14, 0),
-         datetime(2013, 5, 1, 16, 0)),
-        (datetime(2013, 7, 1, 14, 0),
-         datetime(2013, 7, 1, 16, 0)),
-        (datetime(2013, 9, 1, 14, 0),
-         datetime(2013, 9, 1, 16, 0)),
-        (datetime(2013, 11, 1, 14, 0),
-         datetime(2013, 11, 1, 16, 0)),
-        (datetime(2014, 1, 1, 14, 0),
-         datetime(2014, 1, 1, 16, 0))
+        (dt.datetime(2013, 3, 1, 14, 0),
+         dt.datetime(2013, 3, 1, 16, 0)),
+        (dt.datetime(2013, 5, 1, 14, 0),
+         dt.datetime(2013, 5, 1, 16, 0)),
+        (dt.datetime(2013, 7, 1, 14, 0),
+         dt.datetime(2013, 7, 1, 16, 0)),
+        (dt.datetime(2013, 9, 1, 14, 0),
+         dt.datetime(2013, 9, 1, 16, 0)),
+        (dt.datetime(2013, 11, 1, 14, 0),
+         dt.datetime(2013, 11, 1, 16, 0)),
+        (dt.datetime(2014, 1, 1, 14, 0),
+         dt.datetime(2014, 1, 1, 16, 0))
     ]
     dstartend = [
-        (date(2013, 3, 1,),
-         date(2013, 3, 2,)),
-        (date(2013, 5, 1,),
-         date(2013, 5, 2,)),
-        (date(2013, 7, 1,),
-         date(2013, 7, 2,)),
-        (date(2013, 9, 1,),
-         date(2013, 9, 2,)),
-        (date(2013, 11, 1),
-         date(2013, 11, 2)),
-        (date(2014, 1, 1,),
-         date(2014, 1, 2,))
+        (dt.date(2013, 3, 1,),
+         dt.date(2013, 3, 2,)),
+        (dt.date(2013, 5, 1,),
+         dt.date(2013, 5, 2,)),
+        (dt.date(2013, 7, 1,),
+         dt.date(2013, 7, 2,)),
+        (dt.date(2013, 9, 1,),
+         dt.date(2013, 9, 2,)),
+        (dt.date(2013, 11, 1),
+         dt.date(2013, 11, 2)),
+        (dt.date(2014, 1, 1,),
+         dt.date(2014, 1, 2,))
     ]
     offset_berlin = [
-        timedelta(0, 3600),
-        timedelta(0, 7200),
-        timedelta(0, 7200),
-        timedelta(0, 7200),
-        timedelta(0, 3600),
-        timedelta(0, 3600)
+        dt.timedelta(0, 3600),
+        dt.timedelta(0, 7200),
+        dt.timedelta(0, 7200),
+        dt.timedelta(0, 7200),
+        dt.timedelta(0, 3600),
+        dt.timedelta(0, 3600)
     ]
 
     offset_utc = [
-        timedelta(0, 0),
-        timedelta(0, 0),
-        timedelta(0, 0),
-        timedelta(0, 0),
-        timedelta(0, 0),
-        timedelta(0, 0),
+        dt.timedelta(0, 0),
+        dt.timedelta(0, 0),
+        dt.timedelta(0, 0),
+        dt.timedelta(0, 0),
+        dt.timedelta(0, 0),
+        dt.timedelta(0, 0),
     ]
 
     offset_none = [None, None, None, None, None, None]
 
     def test_expand_dt(self):
         vevent = _get_vevent(event_dt)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert dtstart == self.dtstartend_berlin
         assert [start.utcoffset()
                 for start, _ in dtstart] == self.offset_berlin
@@ -319,7 +319,7 @@ class TestExpand(object):
 
     def test_expand_dtb(self):
         vevent = _get_vevent(event_dtb)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert dtstart == self.dtstartend_berlin
         assert [start.utcoffset()
                 for start, _ in dtstart] == self.offset_berlin
@@ -327,77 +327,77 @@ class TestExpand(object):
 
     def test_expand_dttz(self):
         vevent = _get_vevent(event_dttz)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert dtstart == self.dtstartend_utc
         assert [start.utcoffset() for start, _ in dtstart] == self.offset_utc
         assert [end.utcoffset() for _, end in dtstart] == self.offset_utc
 
     def test_expand_dtf(self):
         vevent = _get_vevent(event_dtf)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert dtstart == self.dtstartend_float
         assert [start.utcoffset() for start, _ in dtstart] == self.offset_none
         assert [end.utcoffset() for _, end in dtstart] == self.offset_none
 
     def test_expand_d(self):
         vevent = _get_vevent(event_d)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert dtstart == self.dstartend
 
     def test_expand_dtz(self):
         vevent = _get_vevent(event_dtz)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert dtstart == self.dstartend
 
     def test_expand_dtzb(self):
         vevent = _get_vevent(event_dtzb)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert dtstart == self.dstartend
 
     def test_expand_invalid_exdate(self):
         """testing if we can expand an event with EXDATEs that do not much
         its RRULE"""
         vevent = _get_vevent_file('event_invalid_exdate')
-        dtstartl = utils.expand(vevent, berlin)
+        dtstartl = icalendar_helpers.expand(vevent, berlin)
         # TODO test for logging message
         assert dtstartl == [
-            (new_york.localize(datetime(2011, 11, 12, 15, 50)),
-             new_york.localize(datetime(2011, 11, 12, 17, 0))),
-            (new_york.localize(datetime(2011, 11, 19, 15, 50)),
-             new_york.localize(datetime(2011, 11, 19, 17, 0))),
-            (new_york.localize(datetime(2011, 12, 3, 15, 50)),
-             new_york.localize(datetime(2011, 12, 3, 17, 0))),
+            (new_york.localize(dt.datetime(2011, 11, 12, 15, 50)),
+             new_york.localize(dt.datetime(2011, 11, 12, 17, 0))),
+            (new_york.localize(dt.datetime(2011, 11, 19, 15, 50)),
+             new_york.localize(dt.datetime(2011, 11, 19, 17, 0))),
+            (new_york.localize(dt.datetime(2011, 12, 3, 15, 50)),
+             new_york.localize(dt.datetime(2011, 12, 3, 17, 0))),
         ]
 
 
 class TestExpandNoRR(object):
     dtstartend_berlin = [
-        (berlin.localize(datetime(2013, 3, 1, 14, 0)),
-         berlin.localize(datetime(2013, 3, 1, 16, 0))),
+        (berlin.localize(dt.datetime(2013, 3, 1, 14, 0)),
+         berlin.localize(dt.datetime(2013, 3, 1, 16, 0))),
     ]
 
     dtstartend_utc = [
-        (datetime(2013, 3, 1, 14, 0, tzinfo=pytz.utc),
-         datetime(2013, 3, 1, 16, 0, tzinfo=pytz.utc)),
+        (dt.datetime(2013, 3, 1, 14, 0, tzinfo=pytz.utc),
+         dt.datetime(2013, 3, 1, 16, 0, tzinfo=pytz.utc)),
     ]
 
     dtstartend_float = [
-        (datetime(2013, 3, 1, 14, 0),
-         datetime(2013, 3, 1, 16, 0)),
+        (dt.datetime(2013, 3, 1, 14, 0),
+         dt.datetime(2013, 3, 1, 16, 0)),
     ]
     offset_berlin = [
-        timedelta(0, 3600),
+        dt.timedelta(0, 3600),
     ]
 
     offset_utc = [
-        timedelta(0, 0),
+        dt.timedelta(0, 0),
     ]
 
     offset_none = [None]
 
     def test_expand_dt(self):
         vevent = _get_vevent(event_dt_norr)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert dtstart == self.dtstartend_berlin
         assert [start.utcoffset()
                 for start, _ in dtstart] == self.offset_berlin
@@ -405,7 +405,7 @@ class TestExpandNoRR(object):
 
     def test_expand_dtb(self):
         vevent = _get_vevent(event_dtb_norr)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert dtstart == self.dtstartend_berlin
         assert [start.utcoffset()
                 for start, _ in dtstart] == self.offset_berlin
@@ -413,31 +413,31 @@ class TestExpandNoRR(object):
 
     def test_expand_dttz(self):
         vevent = _get_vevent(event_dttz_norr)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert dtstart == self.dtstartend_utc
         assert [start.utcoffset() for start, _ in dtstart] == self.offset_utc
         assert [end.utcoffset() for _, end in dtstart] == self.offset_utc
 
     def test_expand_dtf(self):
         vevent = _get_vevent(event_dtf_norr)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert dtstart == self.dtstartend_float
         assert [start.utcoffset() for start, _ in dtstart] == self.offset_none
         assert [end.utcoffset() for _, end in dtstart] == self.offset_none
 
     def test_expand_d(self):
         vevent = _get_vevent(event_d_norr)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert dtstart == [
-            (date(2013, 3, 1,),
-             date(2013, 3, 2,)),
+            (dt.date(2013, 3, 1,),
+             dt.date(2013, 3, 2,)),
         ]
 
     def test_expand_dtr_exdatez(self):
         """a recurring event with an EXDATE in Zulu time while DTSTART is
         localized"""
         vevent = _get_vevent_file('event_dtr_exdatez')
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert len(dtstart) == 3
 
     def test_expand_rrule_exdate_z(self):
@@ -445,16 +445,16 @@ class TestExpandNoRR(object):
         exdate
         """
         vevent = _get_vevent_file('event_dtr_no_tz_exdatez')
-        vevent = utils.sanitize(vevent, berlin, '', '')
-        dtstart = utils.expand(vevent, berlin)
+        vevent = icalendar_helpers.sanitize(vevent, berlin, '', '')
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert len(dtstart) == 5
         dtstarts = [start for start, end in dtstart]
         assert dtstarts == [
-            berlin.localize(datetime(2012, 4, 3, 10, 0)),
-            berlin.localize(datetime(2012, 5, 3, 10, 0)),
-            berlin.localize(datetime(2012, 7, 3, 10, 0)),
-            berlin.localize(datetime(2012, 8, 3, 10, 0)),
-            berlin.localize(datetime(2012, 9, 3, 10, 0)),
+            berlin.localize(dt.datetime(2012, 4, 3, 10, 0)),
+            berlin.localize(dt.datetime(2012, 5, 3, 10, 0)),
+            berlin.localize(dt.datetime(2012, 7, 3, 10, 0)),
+            berlin.localize(dt.datetime(2012, 8, 3, 10, 0)),
+            berlin.localize(dt.datetime(2012, 9, 3, 10, 0)),
         ]
 
     def test_expand_rrule_notz_until_z(self):
@@ -462,18 +462,18 @@ class TestExpandNoRR(object):
         exdate
         """
         vevent = _get_vevent_file('event_dtr_notz_untilz')
-        vevent = utils.sanitize(vevent, new_york, '', '')
-        dtstart = utils.expand(vevent, new_york)
+        vevent = icalendar_helpers.sanitize(vevent, new_york, '', '')
+        dtstart = icalendar_helpers.expand(vevent, new_york)
         assert len(dtstart) == 7
         dtstarts = [start for start, end in dtstart]
         assert dtstarts == [
-            new_york.localize(datetime(2012, 7, 26, 13, 0)),
-            new_york.localize(datetime(2012, 8, 9, 13, 0)),
-            new_york.localize(datetime(2012, 8, 23, 13, 0)),
-            new_york.localize(datetime(2012, 9, 6, 13, 0)),
-            new_york.localize(datetime(2012, 9, 20, 13, 0)),
-            new_york.localize(datetime(2012, 10, 4, 13, 0)),
-            new_york.localize(datetime(2012, 10, 18, 13, 0)),
+            new_york.localize(dt.datetime(2012, 7, 26, 13, 0)),
+            new_york.localize(dt.datetime(2012, 8, 9, 13, 0)),
+            new_york.localize(dt.datetime(2012, 8, 23, 13, 0)),
+            new_york.localize(dt.datetime(2012, 9, 6, 13, 0)),
+            new_york.localize(dt.datetime(2012, 9, 20, 13, 0)),
+            new_york.localize(dt.datetime(2012, 10, 4, 13, 0)),
+            new_york.localize(dt.datetime(2012, 10, 18, 13, 0)),
         ]
 
 
@@ -580,108 +580,108 @@ class TestSpecial(object):
 
     def test_count(self):
         vevent = _get_vevent(vevent_count)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         starts = [start for start, _ in dtstart]
         assert len(starts) == 18
-        assert dtstart[0][0] == datetime(2014, 2, 3, 7, 0)
-        assert dtstart[-1][0] == datetime(2014, 2, 20, 7, 0)
+        assert dtstart[0][0] == dt.datetime(2014, 2, 3, 7, 0)
+        assert dtstart[-1][0] == dt.datetime(2014, 2, 20, 7, 0)
 
     def test_until_notz(self):
         vevent = _get_vevent(vevent_until_notz)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         starts = [start for start, _ in dtstart]
         assert len(starts) == 18
         assert dtstart[0][0] == berlin.localize(
-            datetime(2014, 2, 3, 7, 0))
+            dt.datetime(2014, 2, 3, 7, 0))
         assert dtstart[-1][0] == berlin.localize(
-            datetime(2014, 2, 20, 7, 0))
+            dt.datetime(2014, 2, 20, 7, 0))
 
     def test_until_d_notz(self):
         vevent = _get_vevent(event_until_d_notz)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         starts = [start for start, _ in dtstart]
         assert len(starts) == 6
-        assert dtstart[0][0] == date(2014, 1, 10)
-        assert dtstart[-1][0] == date(2014, 2, 14)
+        assert dtstart[0][0] == dt.date(2014, 1, 10)
+        assert dtstart[-1][0] == dt.date(2014, 2, 14)
 
     def test_latest_bug(self):
         vevent = _get_vevent(latest_bug)
-        dtstart = utils.expand(vevent, berlin)
-        assert dtstart[0][0] == date(2009, 10, 31)
-        assert dtstart[-1][0] == date(2037, 10, 31)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
+        assert dtstart[0][0] == dt.date(2009, 10, 31)
+        assert dtstart[-1][0] == dt.date(2037, 10, 31)
 
     def test_recurrence_id_with_timezone(self):
         vevent = _get_vevent(recurrence_id_with_timezone)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert len(dtstart) == 1
         assert dtstart[0][0] == berlin.localize(
-            datetime(2013, 11, 13, 19, 0))
+            dt.datetime(2013, 11, 13, 19, 0))
 
     def test_event_exdate_dt(self):
         """recurring event, one date excluded via EXCLUDE"""
         vevent = _get_vevent(event_exdate_dt)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert len(dtstart) == 9
         assert dtstart[0][0] == berlin.localize(
-            datetime(2014, 7, 2, 19, 0))
+            dt.datetime(2014, 7, 2, 19, 0))
         assert dtstart[-1][0] == berlin.localize(
-            datetime(2014, 7, 11, 19, 0))
+            dt.datetime(2014, 7, 11, 19, 0))
 
     def test_event_exdates_dt(self):
         """recurring event, two dates excluded via EXCLUDE"""
         vevent = _get_vevent(event_exdates_dt)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert len(dtstart) == 8
         assert dtstart[0][0] == berlin.localize(
-            datetime(2014, 7, 2, 19, 0))
+            dt.datetime(2014, 7, 2, 19, 0))
         assert dtstart[-1][0] == berlin.localize(
-            datetime(2014, 7, 11, 19, 0))
+            dt.datetime(2014, 7, 11, 19, 0))
 
     def test_event_exdatesl_dt(self):
         """recurring event, three dates exclude via two EXCLUDEs"""
         vevent = _get_vevent(event_exdatesl_dt)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert len(dtstart) == 7
         assert dtstart[0][0] == berlin.localize(
-            datetime(2014, 7, 2, 19, 0))
+            dt.datetime(2014, 7, 2, 19, 0))
         assert dtstart[-1][0] == berlin.localize(
-            datetime(2014, 7, 11, 19, 0))
+            dt.datetime(2014, 7, 11, 19, 0))
 
     def test_event_exdates_remove(self):
         """check if we can remove one more instance"""
         vevent = _get_vevent(event_exdatesl_dt)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert len(dtstart) == 7
 
-        exdate1 = pytz.UTC.localize(datetime(2014, 7, 11, 17, 0))
-        utils.delete_instance(vevent, exdate1)
-        dtstart = utils.expand(vevent, berlin)
+        exdate1 = pytz.UTC.localize(dt.datetime(2014, 7, 11, 17, 0))
+        icalendar_helpers.delete_instance(vevent, exdate1)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert len(dtstart) == 6
 
-        exdate2 = berlin.localize(datetime(2014, 7, 9, 19, 0))
-        utils.delete_instance(vevent, exdate2)
-        dtstart = utils.expand(vevent, berlin)
+        exdate2 = berlin.localize(dt.datetime(2014, 7, 9, 19, 0))
+        icalendar_helpers.delete_instance(vevent, exdate2)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert len(dtstart) == 5
 
     def test_event_dt_rrule_invalid_until(self):
         """DTSTART and RRULE:UNTIL should be of the same type, but might not
         be"""
         vevent = _get_vevent(_get_text('event_dt_rrule_invalid_until'))
-        dtstart = utils.expand(vevent, berlin)
-        assert dtstart == [(date(2007, 12, 1), date(2007, 12, 2)),
-                           (date(2008, 1, 1), date(2008, 1, 2)),
-                           (date(2008, 2, 1), date(2008, 2, 2))]
+        dtstart = icalendar_helpers.expand(vevent, berlin)
+        assert dtstart == [(dt.date(2007, 12, 1), dt.date(2007, 12, 2)),
+                           (dt.date(2008, 1, 1), dt.date(2008, 1, 2)),
+                           (dt.date(2008, 2, 1), dt.date(2008, 2, 2))]
 
     def test_event_dt_rrule_invalid_until2(self):
         """same as above, but now dtstart is of type date and until is datetime
         """
         vevent = _get_vevent(_get_text('event_dt_rrule_invalid_until2'))
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert len(dtstart) == 35
-        assert dtstart[0] == (berlin.localize(datetime(2014, 4, 9, 9, 30)),
-                              berlin.localize(datetime(2014, 4, 9, 10, 30)))
-        assert dtstart[-1] == (berlin.localize(datetime(2014, 12, 3, 9, 30)),
-                               berlin.localize(datetime(2014, 12, 3, 10, 30)))
+        assert dtstart[0] == (berlin.localize(dt.datetime(2014, 4, 9, 9, 30)),
+                              berlin.localize(dt.datetime(2014, 4, 9, 10, 30)))
+        assert dtstart[-1] == (berlin.localize(dt.datetime(2014, 12, 3, 9, 30)),
+                               berlin.localize(dt.datetime(2014, 12, 3, 10, 30)))
 
 
 simple_rdate = """BEGIN:VEVENT
@@ -708,30 +708,30 @@ class TestRDate(object):
     """Testing expanding of recurrence rules"""
     def test_simple_rdate(self):
         vevent = _get_vevent(simple_rdate)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert len(dtstart) == 4
 
     def test_rrule_and_rdate(self):
         vevent = _get_vevent(rrule_and_rdate)
-        dtstart = utils.expand(vevent, berlin)
+        dtstart = icalendar_helpers.expand(vevent, berlin)
         assert len(dtstart) == 7
 
     def test_rrule_past(self):
         vevent = _get_vevent_file('event_r_past')
         assert vevent is not None
-        dtstarts = utils.expand(vevent, berlin)
+        dtstarts = icalendar_helpers.expand(vevent, berlin)
         assert len(dtstarts) == 73
-        assert dtstarts[0][0] == date(1965, 4, 23)
-        assert dtstarts[-1][0] == date(2037, 4, 23)
+        assert dtstarts[0][0] == dt.date(1965, 4, 23)
+        assert dtstarts[-1][0] == dt.date(2037, 4, 23)
 
     def test_rdate_date(self):
         vevent = _get_vevent_file('event_d_rdate')
-        dtstarts = utils.expand(vevent, berlin)
+        dtstarts = icalendar_helpers.expand(vevent, berlin)
         assert len(dtstarts) == 4
-        assert dtstarts == [(date(2015, 8, 12), date(2015, 8, 13)),
-                            (date(2015, 8, 13), date(2015, 8, 14)),
-                            (date(2015, 8, 14), date(2015, 8, 15)),
-                            (date(2015, 8, 15), date(2015, 8, 16))]
+        assert dtstarts == [(dt.date(2015, 8, 12), dt.date(2015, 8, 13)),
+                            (dt.date(2015, 8, 13), dt.date(2015, 8, 14)),
+                            (dt.date(2015, 8, 14), dt.date(2015, 8, 15)),
+                            (dt.date(2015, 8, 15), dt.date(2015, 8, 16))]
 
 
 noend_date = """
@@ -770,36 +770,36 @@ class TestSanitize(object):
 
     def test_noend_date(self):
         vevent = _get_vevent(noend_date)
-        vevent = utils.sanitize(vevent, berlin, '', '')
-        assert vevent['DTSTART'].dt == date(2014, 8, 29)
-        assert vevent['DTEND'].dt == date(2014, 8, 30)
+        vevent = icalendar_helpers.sanitize(vevent, berlin, '', '')
+        assert vevent['DTSTART'].dt == dt.date(2014, 8, 29)
+        assert vevent['DTEND'].dt == dt.date(2014, 8, 30)
 
     def test_noend_datetime(self):
         vevent = _get_vevent(noend_datetime)
-        vevent = utils.sanitize(vevent, berlin, '', '')
-        assert vevent['DTSTART'].dt == date(2014, 8, 29)
-        assert vevent['DTEND'].dt == date(2014, 8, 30)
+        vevent = icalendar_helpers.sanitize(vevent, berlin, '', '')
+        assert vevent['DTSTART'].dt == dt.date(2014, 8, 29)
+        assert vevent['DTEND'].dt == dt.date(2014, 8, 30)
 
     def test_duration(self):
         vevent = _get_vevent_file('event_dtr_exdatez')
-        vevent = utils.sanitize(vevent, berlin, '', '')
+        vevent = icalendar_helpers.sanitize(vevent, berlin, '', '')
 
     def test_instant(self):
         vevent = _get_vevent(instant)
-        assert vevent['DTEND'].dt - vevent['DTSTART'].dt == timedelta()
-        vevent = utils.sanitize(vevent, berlin, '', '')
-        assert vevent['DTEND'].dt - vevent['DTSTART'].dt == timedelta(hours=1)
+        assert vevent['DTEND'].dt - vevent['DTSTART'].dt == dt.timedelta()
+        vevent = icalendar_helpers.sanitize(vevent, berlin, '', '')
+        assert vevent['DTEND'].dt - vevent['DTSTART'].dt == dt.timedelta(hours=1)
 
 
 class TestIsAware():
     def test_naive(self):
-        assert utils.is_aware(datetime.now()) is False
+        assert utils.is_aware(dt.datetime.now()) is False
 
     def test_berlin(self):
-        assert utils.is_aware(BERLIN.localize(datetime.now())) is True
+        assert utils.is_aware(BERLIN.localize(dt.datetime.now())) is True
 
     def test_bogota(self):
-        assert utils.is_aware(BOGOTA.localize(datetime.now())) is True
+        assert utils.is_aware(BOGOTA.localize(dt.datetime.now())) is True
 
     def test_utc(self):
-        assert utils.is_aware(pytz.UTC.localize(datetime.now())) is True
+        assert utils.is_aware(pytz.UTC.localize(dt.datetime.now())) is True
